@@ -19,6 +19,7 @@ def main():
         "Accept": "application/json",
         "Content-Type": "application/json",
     }
+
     with open(settings.file_path, "r", encoding="utf-8") as f:
         csv_file = csv.reader(f, delimiter=";")
 
@@ -26,7 +27,7 @@ def main():
             if index == 0:
                 continue
 
-            produto_estoque = Produto(row[0], row[1].replace(",", "."), row[2])
+            produto_estoque = Produto(row[0], row[1].replace(",", "."), row[2].replace(",", "."))
 
             skyhub_controller = SkyhubController(
                 credentials=headers_skyhub,
@@ -47,13 +48,11 @@ def main():
                 print(produto_skyhub)
                 if produto_skyhub.price != row[1] or produto_skyhub.qty != row[2]:
                     skyhub_controller.atualiza_produto(produto_estoque)
-                    pass
 
             if produto_bling:
                 print(produto_bling)
                 if produto_bling.price != row[1] or produto_bling.qty != row[2]:
                     bling_controller.atualiza_produto(produto_estoque)
-                    pass
 
 
 if __name__ == "__main__":
