@@ -2,9 +2,11 @@ import logging
 
 import requests
 
+from skyhub.loggin_config import *
 from skyhub.models.produto import Produto
 
-logger = logging.Logger(__name__)
+logger = logging.getLogger(__name__)
+logger.addHandler(f_handler)
 
 
 class SkyhubController:
@@ -34,6 +36,7 @@ class SkyhubController:
         url = f"{self.base_url}/{produto.sku}"
         response = self.request.put(url, data=produtoJSON, headers=self.credentials)
 
+        print(response.status_code)
         if response.status_code == 204:
             logger.info(f"O produto '{produto.sku}' foi atualizado.")
             return True
